@@ -2,12 +2,20 @@ from pydantic import BaseModel
 from typing import Optional, Any, List
 from enum import IntEnum
 
+class SimulationStage(IntEnum):
+    DATAPREPARATION = 1
+    LONGPERIOD = 2
+    LANDMARKET = 3
+    SHORTPERIOD = 4
+    REALISATION = 5
 class SimulationScenario(BaseModel):
     id: Optional[int] = None
     populationId: int
     yearId: int
     ignoreLP: Optional[bool]
     ignoreLMM: Optional[bool]
+    yearToContinueFrom: Optional[int] = 0
+    stageToContinueFrom: Optional[SimulationStage] = SimulationStage.DATAPREPARATION
     shortTermModelBranch: str
     longTermModelBranch: str
     horizon: int
@@ -35,13 +43,6 @@ class OverallStatus(IntEnum):
     CANCELLED = 2
     COMPLETED = 3
     ERROR = 4
-
-class SimulationStage(IntEnum):
-    DATAPREPARATION = 1
-    LONGPERIOD = 2
-    LANDMARKET = 3
-    SHORTPERIOD = 4
-    REALISATION = 5
     
 class SimulationRun(BaseModel):
     id: Optional[int] = None
@@ -50,6 +51,6 @@ class SimulationRun(BaseModel):
     overallStatus: OverallStatus
     currentStage: SimulationStage
     currentYear: int
-    currentSubStage: str
+    currentSubstage: str
     currentStageProgress: int
     currentSubStageProgress: int
